Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type API ¶
type API struct {
// contains filtered or unexported fields
}
API represents the CDN API ojbect
type Conf ¶
type Conf struct {
Address string `yaml:"address"`
Port int `yaml:"port"`
CertFile string `yaml:"cert"`
KeyFile string `yaml:"key"`
}
Conf is the configuration for the API endpoint used to purge entries from the cache
func DefaultConf ¶
func DefaultConf() Conf
DefaultConf returns an API configuration with some defaults
type PurgeRequest ¶
type PurgeRequest struct {
Resource string `json:"resource"`
}
PurgeRequest is used to receive a call to purge an item from the cache
Click to show internal directories.
Click to hide internal directories.